Welcome to j-chess-lib's documentation!
======================================


.. list-table::
   :widths: 25 25

   * -
     - Version
   * - Library
     - |version|
   * - Server-Schema
     - |schema_version|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
